@@ -1,3 +1,5 @@
+import torch as T
+
 class MetricBase(object):
-    def __call__(self, y_pred, y_true):
+    def __call__(self, y_pred: T.Tensor, y_true: T.Tensor):
         raise NotImplementedError('Missing __call__ implementation for metric')
\ No newline at end of file
