@@ -1,3 +1,6 @@
+from  tests.test_metrics import TestMetrics
+import unittest
+
 import examples.multiple_inputs.train as multiple_inputs_example
 import examples.basic.train as basic_example
 import examples.scheduler_step_on_batch_end.train as scheduler_step_on_batch_end_example
@@ -7,7 +10,7 @@ import examples.keras_decay_scheduler.train as keras_decay_scheduler_example
 import examples.accumulate_grads.train as accumulate_grads_example
 import examples.train_evaluate_predict.train as train_evaluate_predict_example
 
-
+# EXAMPLES
 basic_example.run()
 scheduler_step_on_batch_end_example.run()
 multiple_inputs_example.run()
@@ -15,4 +18,9 @@ data_loader_example.run()
 save_and_load_example.run()
 keras_decay_scheduler_example.run()
 accumulate_grads_example.run()
-train_evaluate_predict_example.run()
\ No newline at end of file
+train_evaluate_predict_example.run()
+print('----------------------------------------------------------------------')
+print('Ran all examples')
+
+# TESTS
+unittest.main()
